@@ -1,13 +1,9 @@
 // -*- mode: js2; indent-tabs-mode: nil; js2-basic-offset: 4 -*-
+/* exported init enable disable */
 
-const Gio = imports.gi.Gio;
-const Meta = imports.gi.Meta;
-const Clutter = imports.gi.Clutter;
-const St = imports.gi.St;
-const Mainloop = imports.mainloop;
+const { Clutter, Gio, GObject, Meta, St } = imports.gi;
 const PanelMenu = imports.ui.panelMenu;
 const PopupMenu = imports.ui.popupMenu;
-const Panel = imports.ui.panel;
 
 const Gettext = imports.gettext.domain('gnome-shell-extensions');
 const _ = Gettext.gettext;
@@ -15,23 +11,24 @@ const _ = Gettext.gettext;
 const Main = imports.ui.main;
 
 const ExtensionUtils = imports.misc.extensionUtils;
-const Me = ExtensionUtils.getCurrentExtension();
-const Convenience = Me.imports.convenience;
 
 const WORKSPACE_SCHEMA = 'org.gnome.desktop.wm.preferences';
 const WORKSPACE_KEY = 'workspace-names';
 
+let WorkspaceIndicator = GObject.registerClass(
 class WorkspaceIndicator extends PanelMenu.Button {
-    constructor() {
-        super(0.0, _("Workspace Indicator"));
+    _init() {
+        super._init(0.0, _('Workspace Indicator'));
 
         let workspaceManager = global.workspace_manager;
 
         this._currentWorkspace = workspaceManager.get_active_workspace().index();
-        this.statusLabel = new St.Label({ y_align: Clutter.ActorAlign.CENTER,
-                                          text: this._labelText() });
+        this.statusLabel = new St.Label({
+            y_align: Clutter.ActorAlign.CENTER,
+            text: this._labelText()
+        });
 
-        this.actor.add_actor(this.statusLabel);
+        this.add_actor(this.statusLabel);
 
         this.workspacesItems = [];
         this._workspaceSection = new PopupMenu.PopupMenuSection();
@@ -45,7 +42,7 @@ class WorkspaceIndicator extends PanelMenu.Button {
         this._workspaceManagerSignals.push(workspaceManager.connect_after('workspace-switched',
                                                                           this._updateIndicator.bind(this)));
 
-        this.actor.connect('scroll-event', this._onScrollEvent.bind(this));
+        this.connect('scroll-event', this._onScrollEvent.bind(this));
         this._createWorkspacesSection();
 
         //styling
@@ -53,11 +50,11 @@ class WorkspaceIndicator extends PanelMenu.Button {
 
         this._settings = new Gio.Settings({ schema_id: WORKSPACE_SCHEMA });
         this._settingsChangedId =
-            this._settings.connect('changed::' + WORKSPACE_KEY,
+            this._settings.connect(`changed::${WORKSPACE_KEY}`,
                                    this._createWorkspacesSection.bind(this));
     }
 
-    destroy() {
+    _onDestroy() {
         for (let i = 0; i < this._workspaceManagerSignals.length; i++)
             global.workspace_manager.disconnect(this._workspaceManagerSignals[i]);
 
@@ -66,7 +63,7 @@ class WorkspaceIndicator extends PanelMenu.Button {
             this._settingsChangedId = 0;
         }
 
-        super.destroy();
+        super._onDestroy();
     }
 
     _updateIndicator() {
@@ -78,7 +75,7 @@ class WorkspaceIndicator extends PanelMenu.Button {
     }
 
     _labelText(workspaceIndex) {
-        if(workspaceIndex == undefined) {
+        if (workspaceIndex == undefined) {
             workspaceIndex = this._currentWorkspace;
             return (workspaceIndex + 1).toString();
         }
@@ -93,13 +90,12 @@ class WorkspaceIndicator extends PanelMenu.Button {
         this._currentWorkspace = workspaceManager.get_active_workspace().index();
 
         let i = 0;
-        for(; i < workspaceManager.n_workspaces; i++) {
+        for (; i < workspaceManager.n_workspaces; i++) {
             this.workspacesItems[i] = new PopupMenu.PopupMenuItem(this._labelText(i));
             this._workspaceSection.addMenuItem(this.workspacesItems[i]);
             this.workspacesItems[i].workspaceId = i;
             this.workspacesItems[i].label_actor = this.statusLabel;
-            let self = this;
-            this.workspacesItems[i].connect('activate', (actor, event) => {
+            this.workspacesItems[i].connect('activate', (actor, _event) => {
                 this._activate(actor.workspaceId);
             });
 
@@ -113,7 +109,7 @@ class WorkspaceIndicator extends PanelMenu.Button {
     _activate(index) {
         let workspaceManager = global.workspace_manager;
 
-        if(index >= 0 && index <  workspaceManager.n_workspaces) {
+        if (index >= 0 && index <  workspaceManager.n_workspaces) {
             let metaWorkspace = workspaceManager.get_workspace_by_index(index);
             metaWorkspace.activate(global.get_current_time());
         }
@@ -133,10 +129,10 @@ class WorkspaceIndicator extends PanelMenu.Button {
         let newIndex = global.workspace_manager.get_active_workspace().index() + diff;
         this._activate(newIndex);
     }
-};
+});
 
-function init(meta) {
-    Convenience.initTranslations();
+function init() {
+    ExtensionUtils.initTranslations();
 }
 
 let _indicator;
